@@ -51,6 +51,7 @@ def get_video_duration(video_path: str):
     ffprobe_cmd = 'ffprobe -i "'+video_path+'" -show_entries format=duration -v quiet -of csv="p=0"'
     a=os.popen(ffprobe_cmd)
     duration_info = float(a.read())
+    #duration_info = float(a.buffer.read().decode('utf-8'))
     return duration_info
 
 def takescreenshot(file,screenshotaddress,screenshotnum):
@@ -292,14 +293,16 @@ class mediafile(object):
         if self.getmediainfo_done==1:
             return self.mediainfo
         a=os.popen("mediainfo \""+self.address+'"')
-        res=a.read(encoding='utf-8')
+        #res=a.read()
+        res=a.buffer.read().decode('utf-8')
         self.dealsubtext(res)
         self.dealaudio(res)
         ss=res.split('\n')
         ss[1]=':'.join([ss[1].split(':')[0],' '+self.filename])
         self.mediainfo='\n'.join(ss)
         a=os.popen("mediainfo --Output=JSON \""+self.address+'"')
-        res_json=a.read(encoding='utf-8')
+        #res_json=a.read()
+        res_json=a.buffer.read().decode('utf-8')
         media_json=json.loads(res_json)
         self.mediainfo_json=media_json
         self.Format            =media_json['media']['track'][0]['Format']
